@@ -34,16 +34,16 @@ jmvreliClass <- if (requireNamespace('jmvcore', quietly=TRUE)) R6::R6Class(
             tex_res =   paste0(
                 "Coefficient of Variation (%): ",
                 round(res$cv$est*100,2),
-                "\n",
+                "<br>",
                 "Standard Error of Measurement (SEM): ",
                 round(res$SEM$est,4),
-                "\n",
+                "<br>",
                 "Standard Error of the Estimate (SEE): ",
                 round(res$SEE$est,4),
-                "\n",
+                "<br>",
                 "Standard Error of Prediction (SEP): ",
                 round(res$SEP$est,4),
-                "\n"
+                "<br>"
             )
 
             plot$setState(res)
@@ -59,12 +59,26 @@ jmvreliClass <- if (requireNamespace('jmvcore', quietly=TRUE)) R6::R6Class(
             }
 
         },
-        .plot=function(image, ...) {
+        .plot=function(image, ggtheme, ...) {
 
             if (is.null(image$state))
                 return(FALSE)
 
-            plotpr = plot(image$state)
+            plotpr = plot(image$state)+
+            ggtheme +
+              theme(legend.position = "none")
+            #theme(#strip.text = element_text(face = "bold", size = 11),
+            #legend.text = element_text(face = "bold", size = 11),
+            #legend.title = element_text(face = "bold", size = 11),
+            #axis.text.x = element_text(face = "bold", size = 11),
+            #axis.text.y = element_text(face = "bold", size = 11),
+            #axis.title.x = element_text(face = "bold", size = 11),
+            #panel.grid.major = element_blank(),
+            #panel.grid.minor = element_blank(),
+            #panel.background = element_rect(fill = "transparent",colour = NA),
+            #plot.background = element_rect(fill = "transparent",colour = NA),
+            #legend.background = element_rect(fill = "transparent",colour = NA),
+            #legend.position = "none")
 
 
             print(plotpr)
