@@ -70,7 +70,15 @@ plot.powerCurve <- function(x, ...){
       facet_grid(agree.level~conf.level,
                  labeller = label_both) +
       labs(color = "Delta") +
-      scale_color_viridis_d()
+      scale_color_viridis_d() +
+      theme(
+        panel.background = element_rect(fill='transparent'), #transparent panel bg
+        plot.background = element_rect(fill='transparent', color=NA), #transparent plot bg
+        #panel.grid.major = element_blank(), #remove major gridlines
+        #panel.grid.minor = element_blank(), #remove minor gridlines
+        legend.background = element_rect(fill='transparent'), #transparent legend bg
+        legend.box.background = element_rect(fill='transparent') #transparent legend panel
+      )
     return(plot_out)
 
 }
