@@ -296,7 +296,15 @@ plot_bias = function(x,
       y = "Residuals",
       x = "Mean of both methods"
     ) +
-    theme_bw()
+    theme_bw()+
+    theme(
+      panel.background = element_rect(fill='transparent'), #transparent panel bg
+      plot.background = element_rect(fill='transparent', color=NA), #transparent plot bg
+      panel.grid.major = element_blank(), #remove major gridlines
+      panel.grid.minor = element_blank(), #remove minor gridlines
+      legend.background = element_rect(fill='transparent'), #transparent legend bg
+      legend.box.background = element_rect(fill='transparent') #transparent legend panel
+    )
 }
 
 # Check agree_test -----
@@ -335,7 +343,15 @@ check_reli = function(x){
                    x_lab = "Fitted values") +
     labs(caption = paste0("Heteroskedasticity", " \n",
                           "Breusch-Pagan Test: p = ",
-                          signif(p_val_het,4)))
+                          signif(p_val_het,4)))+
+    theme(
+      panel.background = element_rect(fill='transparent'), #transparent panel bg
+      plot.background = element_rect(fill='transparent', color=NA), #transparent plot bg
+      panel.grid.major = element_blank(), #remove major gridlines
+      panel.grid.minor = element_blank(), #remove minor gridlines
+      legend.background = element_rect(fill='transparent'), #transparent legend bg
+      legend.box.background = element_rect(fill='transparent') #transparent legend panel
+    )
 
 
   ## Normality ------------
@@ -357,11 +373,26 @@ check_reli = function(x){
   ) +
     labs(caption = paste0("Normality", " \n",
                           norm_text, ": p = ",
-                          signif(norm_test$p.value,4)))
+                          signif(norm_test$p.value,4))) +
+    theme(
+      panel.background = element_rect(fill='transparent'), #transparent panel bg
+      plot.background = element_rect(fill='transparent', color=NA), #transparent plot bg
+      panel.grid.major = element_blank(), #remove major gridlines
+      panel.grid.minor = element_blank(), #remove minor gridlines
+      legend.background = element_rect(fill='transparent'), #transparent legend bg
+      legend.box.background = element_rect(fill='transparent') #transparent legend panel
+    )
 
-
-  return(list(p_norm = p_norm,
-              p_het = p_het))
+  all_checks = wrap_plots(p_norm, p_het, ncol = 2)& plot_annotation(
+    theme = theme(
+      panel.background = element_rect(fill='transparent'), #transparent panel bg
+      plot.background = element_rect(fill='transparent', color=NA), #transparent plot bg
+      panel.grid.major = element_blank(), #remove major gridlines
+      panel.grid.minor = element_blank(), #remove minor gridlines
+      legend.background = element_rect(fill='transparent'), #transparent legend bg
+      legend.box.background = element_rect(fill='transparent') #transparent legend panel
+    ))
+  return(all_checks)
 }
 
 # Deming ----
