@@ -83,7 +83,7 @@ simple_ba_plot = function(x,
   y_lab = y_name
   df_loa2 = df_loa
   df_loa2$x = scalemin
-  df_loa2$text = factor(c("Bias", "Lower LoA", "Upper LoA"),
+  df_loa2$text = factor(rownames(df_loa),
                        levels = c("Upper LoA", "Bias", "Lower LoA"))
   df$mean = (df$x + df$y)/2
   df$delta = df$x - df$y
